==> qtjambi-qt3danimation-jre8-5.15.5-sources.jar: io/qt/qt3d/animation/QAnimationClip.java <==
package io.qt.qt3d.animation;


/**
 * <p>Specifies key frame animation data</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3danimation-qanimationclip.html">Qt3DAnimation::QAnimationClip</a></p>
 */
public class QAnimationClip extends io.qt.qt3d.animation.QAbstractAnimationClip
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAnimationClip.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qanimationclip.html#clipData-prop">Qt3DAnimation::QAnimationClip::clipDataChanged(Qt3DAnimation::QAnimationClipData)</a></p>
     */
    @io.qt.QtPropertyNotify(name="clipData")
    public final Signal1<io.qt.qt3d.animation.QAnimationClipData> clipDataChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QAnimationClip(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QAnimationClip() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QAnimationClip(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAnimationClip instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qanimationclip.html#clipData">Qt3DAnimation::QAnimationClip::clipData()const</a></p>
     */
    @io.qt.QtPropertyReader(name="clipData")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.animation.QAnimationClipData clipData(){
        return clipData_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.animation.QAnimationClipData clipData_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qanimationclip.html#setClipData">Qt3DAnimation::QAnimationClip::setClipData(Qt3DAnimation::QAnimationClipData)</a></p>
     */
    @io.qt.QtPropertyWriter(name="clipData")
    public final void setClipData(io.qt.qt3d.animation.QAnimationClipData clipData){
        setClipData_native_cref_Qt3DAnimation_QAnimationClipData(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(clipData));
    }
    
    private native void setClipData_native_cref_Qt3DAnimation_QAnimationClipData(long __this__nativeId, long clipData);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAnimationClip(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAnimationClip(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAnimationClip instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3danimation-jre8-6.2-sources.jar: io/qt/qt3d/animation/QAnimationClip.java <==
package io.qt.qt3d.animation;


/**
 * <p>Specifies key frame animation data</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3danimation-qanimationclip.html">Qt3DAnimation::QAnimationClip</a></p>
 */
public class QAnimationClip extends io.qt.qt3d.animation.QAbstractAnimationClip
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAnimationClip.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qanimationclip.html#clipData-prop">Qt3DAnimation::QAnimationClip::clipDataChanged(Qt3DAnimation::QAnimationClipData)</a></p>
     */
    @io.qt.QtPropertyNotify(name="clipData")
    public final Signal1<io.qt.qt3d.animation.QAnimationClipData> clipDataChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QAnimationClip(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QAnimationClip() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QAnimationClip(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAnimationClip instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qanimationclip.html#clipData">Qt3DAnimation::QAnimationClip::clipData()const</a></p>
     */
    @io.qt.QtPropertyReader(name="clipData")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.animation.QAnimationClipData clipData(){
        return clipData_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.animation.QAnimationClipData clipData_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qanimationclip.html#setClipData">Qt3DAnimation::QAnimationClip::setClipData(Qt3DAnimation::QAnimationClipData)</a></p>
     */
    @io.qt.QtPropertyWriter(name="clipData")
    public final void setClipData(io.qt.qt3d.animation.QAnimationClipData clipData){
        setClipData_native_cref_Qt3DAnimation_QAnimationClipData(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(clipData));
    }
    
    private native void setClipData_native_cref_Qt3DAnimation_QAnimationClipData(long __this__nativeId, long clipData);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAnimationClip(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAnimationClip(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAnimationClip instance, QDeclarativeConstructor constructor);
    
}
